@@ -1,21 +1,19 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-from __future__ import print_function
+#!/usr/bin/env python3
 
 from plumbum import colors
 
 with colors.fg.red:
     print("This is in red")
 
-print("This is completly restored, even if an exception is thrown!")
+print("This is completely restored, even if an exception is thrown!")
 
-print("The library will restore color on exiting automatially.")
+print("The library will restore color on exiting automatically.")
 print(colors.bold["This is bold and exciting!"])
 print(colors.bg.cyan | "This is on a cyan background.")
 print(colors.fg[42] | "If your terminal supports 256 colors, this is colorful!")
 print()
 for c in colors:
-    print(c + u"\u2588", end="")
+    print(c + "\u2588", end="")
 colors.reset()
 print()
 print("Colors can be reset " + colors.underline["Too!"])
