@@ -5,17 +5,19 @@ from plumbum.commands.processes import CommandNotFound, ProcessExecutionError, r
 def make_concurrent(self, rhs):
     if not isinstance(rhs, BaseCommand):
         raise TypeError("rhs must be an instance of BaseCommand")
+
     if isinstance(self, ConcurrentCommand):
         if isinstance(rhs, ConcurrentCommand):
             self.commands.extend(rhs.commands)
         else:
             self.commands.append(rhs)
         return self
-    elif isinstance(rhs, ConcurrentCommand):
+
+    if isinstance(rhs, ConcurrentCommand):
         rhs.commands.insert(0, self)
         return rhs
-    else:
-        return ConcurrentCommand(self, rhs)
+
+    return ConcurrentCommand(self, rhs)
 
 
 BaseCommand.__and__ = make_concurrent
@@ -69,7 +71,7 @@ class ConcurrentCommand(BaseCommand):
         for cmd in self.commands:
             form.extend(cmd.formulate(level, args))
             form.append("&")
-        return form + [")"]
+        return [*form, ")"]
 
     def popen(self, *args, **kwargs):
         return ConcurrentPopen([cmd[args].popen(**kwargs) for cmd in self.commands])
@@ -82,8 +84,8 @@ class ConcurrentCommand(BaseCommand):
             ]
         if not args:
             return self
-        else:
-            return ConcurrentCommand(*(cmd[args] for cmd in self.commands))
+
+        return ConcurrentCommand(*(cmd[args] for cmd in self.commands))
 
 
 class Cluster:
@@ -164,7 +166,7 @@ class ClusterSession:
         self.close()
 
     def __del__(self):
-        try:
+        try:  # noqa: 167
             self.close()
         except Exception:
             pass
