@@ -1,9 +1,12 @@
-# -*- coding: utf-8 -*-
-from abc import abstractmethod
+import collections.abc
+import contextlib
+import inspect
+from abc import ABC, abstractmethod
+from typing import Callable, Generator, List, Union
 
 from plumbum import local
 from plumbum.cli.i18n import get_translation_for
-from plumbum.lib import getdoc, six
+from plumbum.lib import getdoc
 
 _translation = get_translation_for(__name__)
 _, ngettext = _translation.gettext, _translation.ngettext
@@ -12,56 +15,40 @@ _, ngettext = _translation.gettext, _translation.ngettext
 class SwitchError(Exception):
     """A general switch related-error (base class of all other switch errors)"""
 
-    pass
-
 
 class PositionalArgumentsError(SwitchError):
     """Raised when an invalid number of positional arguments has been given"""
 
-    pass
-
 
 class SwitchCombinationError(SwitchError):
     """Raised when an invalid combination of switches has been given"""
 
-    pass
-
 
 class UnknownSwitch(SwitchError):
     """Raised when an unrecognized switch has been given"""
 
-    pass
-
 
 class MissingArgument(SwitchError):
     """Raised when a switch requires an argument, but one was not provided"""
 
-    pass
-
 
 class MissingMandatorySwitch(SwitchError):
     """Raised when a mandatory switch has not been given"""
 
-    pass
-
 
 class WrongArgumentType(SwitchError):
     """Raised when a switch expected an argument of some type, but an argument of a wrong
     type has been given"""
 
-    pass
-
 
 class SubcommandError(SwitchError):
     """Raised when there's something wrong with sub-commands"""
 
-    pass
-
 
 # ===================================================================================================
 # The switch decorator
 # ===================================================================================================
-class SwitchInfo(object):
+class SwitchInfo:
     def __init__(self, **kwargs):
         for k, v in kwargs.items():
             setattr(self, k, v)
@@ -71,11 +58,11 @@ def switch(
     names,
     argtype=None,
     argname=None,
-    list=False,
+    list=False,  # pylint: disable=redefined-builtin
     mandatory=False,
     requires=(),
     excludes=(),
-    help=None,
+    help=None,  # pylint: disable=redefined-builtin
     overridable=False,
     group="Switches",
     envname=None,
@@ -165,7 +152,7 @@ def switch(
 
     :returns: The decorated function (with a ``_switch_info`` attribute)
     """
-    if isinstance(names, six.string_types):
+    if isinstance(names, str):
         names = [names]
     names = [n.lstrip("-") for n in names]
     requires = [n.lstrip("-") for n in requires]
@@ -173,11 +160,8 @@ def switch(
 
     def deco(func):
         if argname is None:
-            argspec = six.getfullargspec(func).args
-            if len(argspec) == 2:
-                argname2 = argspec[1]
-            else:
-                argname2 = _("VALUE")
+            argspec = inspect.getfullargspec(func).args
+            argname2 = argspec[1] if len(argspec) == 2 else _("VALUE")
         else:
             argname2 = argname
         help2 = getdoc(func) if help is None else help
@@ -216,7 +200,7 @@ def autoswitch(*args, **kwargs):
 # ===================================================================================================
 # Switch Attributes
 # ===================================================================================================
-class SwitchAttr(object):
+class SwitchAttr:
     """
     A switch that stores its result in an attribute (descriptor). Usage::
 
@@ -235,9 +219,16 @@ class SwitchAttr(object):
     """
 
     ATTR_NAME = "__plumbum_switchattr_dict__"
+    VALUE = _("VALUE")
 
     def __init__(
-        self, names, argtype=str, default=None, list=False, argname=_("VALUE"), **kwargs
+        self,
+        names,
+        argtype=str,
+        default=None,
+        list=False,  # pylint: disable=redefined-builtin
+        argname=VALUE,
+        **kwargs,
     ):
         self.__doc__ = "Sets an attribute"  # to prevent the help message from showing SwitchAttr's docstring
         if default and argtype is not None:
@@ -265,17 +256,16 @@ class SwitchAttr(object):
     def __get__(self, inst, cls):
         if inst is None:
             return self
-        else:
-            return getattr(inst, self.ATTR_NAME, {}).get(self, self._default_value)
+        return getattr(inst, self.ATTR_NAME, {}).get(self, self._default_value)
 
     def __set__(self, inst, val):
         if inst is None:
             raise AttributeError("cannot set an unbound SwitchAttr")
+
+        if not hasattr(inst, self.ATTR_NAME):
+            setattr(inst, self.ATTR_NAME, {self: val})
         else:
-            if not hasattr(inst, self.ATTR_NAME):
-                setattr(inst, self.ATTR_NAME, {self: val})
-            else:
-                getattr(inst, self.ATTR_NAME)[self] = val
+            getattr(inst, self.ATTR_NAME)[self] = val
 
 
 class Flag(SwitchAttr):
@@ -331,7 +321,7 @@ class CountOf(SwitchAttr):
 # ===================================================================================================
 
 
-class positional(object):
+class positional:
     """
     Runs a validator on the main function for a class.
     This should be used like this::
@@ -365,38 +355,39 @@ class positional(object):
         self.kargs = kargs
 
     def __call__(self, function):
-        m = six.getfullargspec(function)
+        m = inspect.getfullargspec(function)
         args_names = list(m.args[1:])
 
-        positional = [None] * len(args_names)
+        positional_list = [None] * len(args_names)
         varargs = None
 
-        for i in range(min(len(positional), len(self.args))):
-            positional[i] = self.args[i]
+        for i in range(min(len(positional_list), len(self.args))):
+            positional_list[i] = self.args[i]
 
         if len(args_names) + 1 == len(self.args):
             varargs = self.args[-1]
 
         # All args are positional, so convert kargs to positional
-        for item in self.kargs:
+        for item, value in self.kargs.items():
             if item == m.varargs:
-                varargs = self.kargs[item]
+                varargs = value
             else:
-                positional[args_names.index(item)] = self.kargs[item]
+                positional_list[args_names.index(item)] = value
 
-        function.positional = positional
+        function.positional = positional_list
         function.positional_varargs = varargs
         return function
 
 
-class Validator(six.ABC):
+class Validator(ABC):
     __slots__ = ()
 
     @abstractmethod
     def __call__(self, obj):
         "Must be implemented for a Validator to work"
 
-    def choices(self, partial=""):
+    # pylint: disable-next=no-self-use
+    def choices(self, partial=""):  # noqa: ARG002
         """Should return set of valid choices, can be given optional partial info"""
         return set()
 
@@ -408,8 +399,9 @@ class Validator(six.ABC):
             for prop in getattr(cls, "__slots__", ()):
                 if prop[0] != "_":
                     slots[prop] = getattr(self, prop)
-        mystrs = ("{} = {}".format(name, slots[name]) for name in slots)
-        return "{}({})".format(self.__class__.__name__, ", ".join(mystrs))
+        mystrs = (f"{name} = {value}" for name, value in slots.items())
+        mystrs_str = ", ".join(mystrs)
+        return f"{self.__class__.__name__}({mystrs_str})"
 
 
 # ===================================================================================================
@@ -434,7 +426,7 @@ class Range(Validator):
         self.end = end
 
     def __repr__(self):
-        return "[{:d}..{:d}]".format(self.start, self.end)
+        return f"[{self.start:d}..{self.end:d}]"
 
     def __call__(self, obj):
         obj = int(obj)
@@ -444,7 +436,7 @@ class Range(Validator):
             )
         return obj
 
-    def choices(self, partial=""):
+    def choices(self, partial=""):  # noqa: ARG002
         # TODO: Add partial handling
         return set(range(self.start, self.end + 1))
 
@@ -464,57 +456,71 @@ class Set(Validator):
                              comparison or not. The default is ``False``
     :param csv: splits the input as a comma-separated-value before validating and returning
                 a list. Accepts ``True``, ``False``, or a string for the separator
+    :param all_markers: When a user inputs any value from this set, all values are iterated
+                        over. Something like {"*", "all"} would be a potential setting for
+                        this option.
     """
 
-    def __init__(self, *values, **kwargs):
-        self.case_sensitive = kwargs.pop("case_sensitive", False)
-        self.csv = kwargs.pop("csv", False)
-        if self.csv is True:
-            self.csv = ","
-        if kwargs:
-            raise TypeError(
-                _("got unexpected keyword argument(s): {0}").format(kwargs.keys())
-            )
+    def __init__(
+        self,
+        *values: Union[str, Callable[[str], str]],
+        case_sensitive: bool = False,
+        csv: Union[bool, str] = False,
+        all_markers: "collections.abc.Set[str]" = frozenset(),
+    ) -> None:
+        self.case_sensitive = case_sensitive
+        if isinstance(csv, bool):
+            self.csv = "," if csv else ""
+        else:
+            self.csv = csv
         self.values = values
+        self.all_markers = all_markers
 
     def __repr__(self):
-        return "{{{0}}}".format(
-            ", ".join(v if isinstance(v, str) else v.__name__ for v in self.values)
-        )
+        items = ", ".join(v if isinstance(v, str) else v.__name__ for v in self.values)
+        return f"{{{items}}}"
 
-    def __call__(self, value, check_csv=True):
+    def _call_iter(
+        self, value: str, check_csv: bool = True
+    ) -> Generator[str, None, None]:
         if self.csv and check_csv:
-            return [self(v.strip(), check_csv=False) for v in value.split(",")]
+            for v in value.split(self.csv):
+                yield from self._call_iter(v.strip(), check_csv=False)
+
         if not self.case_sensitive:
             value = value.lower()
+
         for opt in self.values:
             if isinstance(opt, str):
                 if not self.case_sensitive:
-                    opt = opt.lower()
-                if opt == value:
-                    return opt  # always return original value
+                    opt = opt.lower()  # noqa: PLW2901
+                if opt == value or value in self.all_markers:
+                    yield opt  # always return original value
                 continue
-            try:
-                return opt(value)
-            except ValueError:
-                pass
-        raise ValueError(
-            "Invalid value: {} (Expected one of {})".format(value, self.values)
-        )
+            with contextlib.suppress(ValueError):
+                yield opt(value)
+
+    def __call__(self, value: str, check_csv: bool = True) -> Union[str, List[str]]:
+        items = list(self._call_iter(value, check_csv))
+        if not items:
+            msg = f"Invalid value: {value} (Expected one of {self.values})"
+            raise ValueError(msg)
+        if self.csv and check_csv or len(items) > 1:
+            return items
+        return items[0]
 
     def choices(self, partial=""):
-        choices = {
-            opt if isinstance(opt, str) else "({})".format(opt) for opt in self.values
-        }
+        choices = {opt if isinstance(opt, str) else f"({opt})" for opt in self.values}
+        choices |= self.all_markers
         if partial:
-            choices = {opt for opt in choices if opt.lower().startswith(partial)}
+            return {opt for opt in choices if opt.lower().startswith(partial)}
         return choices
 
 
 CSV = Set(str, csv=True)
 
 
-class Predicate(object):
+class Predicate:
     """A wrapper for a single-argument function with pretty printing"""
 
     def __init__(self, func):
@@ -526,7 +532,8 @@ class Predicate(object):
     def __call__(self, val):
         return self.func(val)
 
-    def choices(self, partial=""):
+    # pylint: disable-next=no-self-use
+    def choices(self, partial=""):  # noqa: ARG002
         return set()
 
 
@@ -543,10 +550,8 @@ def ExistingDirectory(val):
 def MakeDirectory(val):
     p = local.path(val)
     if p.is_file():
-        raise ValueError(
-            "{} is a file, should be nonexistent, or a directory".format(val)
-        )
-    elif not p.exists():
+        raise ValueError(f"{val} is a file, should be nonexistent, or a directory")
+    if not p.exists():
         p.mkdir()
     return p
 
