@@ -275,7 +275,8 @@ class BaseRemoteMachine(BaseMachine):
 
     def session(self, isatty=False, *, new_session=False):
         """Creates a new :class:`ShellSession <plumbum.session.ShellSession>` object; this invokes the user's
-        shell on the remote machine and executes commands on it over stdin/stdout/stderr"""
+        shell on the remote machine and executes commands on it over stdin/stdout/stderr
+        """
         raise NotImplementedError()
 
     def download(self, src, dst):
@@ -379,7 +380,7 @@ class BaseRemoteMachine(BaseMachine):
             return None
         statres = out.strip().split(",")
         text_mode = statres.pop(0).lower()
-        res = StatRes((int(statres[0], 16),) + tuple(int(sr) for sr in statres[1:]))
+        res = StatRes((int(statres[0], 16), *tuple(int(sr) for sr in statres[1:])))
         res.text_mode = text_mode
         return res
 
@@ -395,7 +396,7 @@ class BaseRemoteMachine(BaseMachine):
     def _path_mkdir(
         self,
         fn,
-        mode=None,  # pylint: disable=unused-argument
+        mode=None,  # noqa: ARG002
         minus_p=True,
     ):
         p_str = "-p " if minus_p else ""
@@ -424,7 +425,7 @@ class BaseRemoteMachine(BaseMachine):
     def _path_read(self, fn):
         data = self["cat"](fn)
         if self.custom_encoding and isinstance(data, str):
-            data = data.encode(self.custom_encoding)
+            return data.encode(self.custom_encoding)
         return data
 
     def _path_write(self, fn, data):
