@@ -1,8 +1,10 @@
-# -*- coding: utf-8 -*-
+import re
+import socket
 import warnings
+from contextlib import closing
 
 from plumbum.commands import ProcessExecutionError, shquote
-from plumbum.lib import IS_WIN32, _setdoc
+from plumbum.lib import IS_WIN32
 from plumbum.machines.local import local
 from plumbum.machines.remote import BaseRemoteMachine
 from plumbum.machines.session import ShellSession
@@ -10,20 +12,37 @@ from plumbum.path.local import LocalPath
 from plumbum.path.remote import RemotePath
 
 
-class SshTunnel(object):
+def _get_free_port():
+    """Attempts to find a free port."""
+    s = socket.socket()
+    with closing(s):
+        s.bind(("localhost", 0))
+        return s.getsockname()[1]
+
+
+class SshTunnel:
     """An object representing an SSH tunnel (created by
     :func:`SshMachine.tunnel <plumbum.machines.remote.SshMachine.tunnel>`)"""
 
-    __slots__ = ["_session", "__weakref__"]
+    __slots__ = ["_session", "_lport", "_dport", "_reverse", "__weakref__"]
 
-    def __init__(self, session):
+    def __init__(self, session, lport, dport, reverse):
         self._session = session
+        self._lport = lport
+        self._dport = dport
+        self._reverse = reverse
+        if reverse and str(dport) == "0" and session._startup_result is not None:
+            # Try to detect assigned remote port.
+            regex = re.compile(
+                r"^Allocated port (\d+) for remote forward to .+$", re.MULTILINE
+            )
+            match = regex.search(session._startup_result[2])
+            if match:
+                self._dport = match.group(1)
 
     def __repr__(self):
-        if self._session.alive():
-            return "<SshTunnel {}>".format(self._session.proc)
-        else:
-            return "<SshTunnel (defunct)>"
+        tunnel = self._session.proc if self._session.alive() else "(defunct)"
+        return f"<SshTunnel {tunnel}>"
 
     def __enter__(self):
         return self
@@ -35,6 +54,21 @@ class SshTunnel(object):
         """Closes(terminates) the tunnel"""
         self._session.close()
 
+    @property
+    def lport(self):
+        """Tunneled port or socket on the local machine."""
+        return self._lport
+
+    @property
+    def dport(self):
+        """Tunneled port or socket on the remote machine."""
+        return self._dport
+
+    @property
+    def reverse(self):
+        """Represents if the tunnel is a reverse tunnel."""
+        return self._reverse
+
 
 class SshMachine(BaseRemoteMachine):
     """
@@ -93,7 +127,6 @@ class SshMachine(BaseRemoteMachine):
         connect_timeout=10,
         new_session=False,
     ):
-
         if ssh_command is None:
             if password is not None:
                 ssh_command = local["sshpass"]["-p", password, "ssh"]
@@ -107,8 +140,9 @@ class SshMachine(BaseRemoteMachine):
 
         scp_args = []
         ssh_args = []
+        self.host = host
         if user:
-            self._fqhost = "{}@{}".format(user, host)
+            self._fqhost = f"{user}@{host}"
         else:
             self._fqhost = host
         if port:
@@ -130,9 +164,8 @@ class SshMachine(BaseRemoteMachine):
         )
 
     def __str__(self):
-        return "ssh://{}".format(self._fqhost)
+        return f"ssh://{self._fqhost}"
 
-    @_setdoc(BaseRemoteMachine)
     def popen(self, args, ssh_opts=(), env=None, cwd=None, **kwargs):
         cmdline = []
         cmdline.extend(ssh_opts)
@@ -149,9 +182,7 @@ class SshMachine(BaseRemoteMachine):
                 cmdline.extend(["cd", str(cwd), "&&"])
             if envdelta:
                 cmdline.append("env")
-                cmdline.extend(
-                    "{}={}".format(k, shquote(v)) for k, v in envdelta.items()
-                )
+                cmdline.extend(f"{k}={shquote(v)}" for k, v in envdelta.items())
             if isinstance(args, (tuple, list)):
                 cmdline.extend(args)
             else:
@@ -164,7 +195,11 @@ class SshMachine(BaseRemoteMachine):
         allowing the command to run "detached" from its controlling TTY or parent.
         Does not return anything. Depreciated (use command.nohup or daemonic_popen).
         """
-        warnings.warn("Use .nohup on the command or use daemonic_popen)", FutureWarning)
+        warnings.warn(
+            "Use .nohup on the command or use daemonic_popen)",
+            FutureWarning,
+            stacklevel=2,
+        )
         self.daemonic_popen(command, cwd=".", stdout=None, stderr=None, append=False)
 
     def daemonic_popen(self, command, cwd=".", stdout=None, stderr=None, append=True):
@@ -181,10 +216,7 @@ class SshMachine(BaseRemoteMachine):
         if stderr is None:
             stderr = "&1"
 
-        if str(cwd) == ".":
-            args = []
-        else:
-            args = ["cd", str(cwd), "&&"]
+        args = [] if str(cwd) == "." else ["cd", str(cwd), "&&"]
         args.append("nohup")
         args.extend(command.formulate())
         args.extend(
@@ -206,7 +238,6 @@ class SshMachine(BaseRemoteMachine):
             proc.stdout.close()
             proc.stderr.close()
 
-    @_setdoc(BaseRemoteMachine)
     def session(self, isatty=False, new_session=False):
         return ShellSession(
             self.popen(
@@ -215,6 +246,7 @@ class SshMachine(BaseRemoteMachine):
             self.custom_encoding,
             isatty,
             self.connect_timeout,
+            host=self.host,
         )
 
     def tunnel(
@@ -223,7 +255,7 @@ class SshMachine(BaseRemoteMachine):
         dport,
         lhost="localhost",
         dhost="localhost",
-        connect_timeout=5,
+        connect_timeout=5,  # noqa: ARG002
         reverse=False,
     ):
         r"""Creates an SSH tunnel from the TCP port (``lport``) of the local machine
@@ -275,58 +307,62 @@ class SshMachine(BaseRemoteMachine):
                 sock.connect(("localhost", 1234))
                 # sock is now tunneled to the MySQL socket on megazord
         """
-        formatted_lhost = "" if lhost is None else "[{}]:".format(lhost)
-        formatted_dhost = "" if dhost is None else "[{}]:".format(dhost)
+        formatted_lhost = "" if lhost is None else f"[{lhost}]:"
+        formatted_dhost = "" if dhost is None else f"[{dhost}]:"
+        if str(lport) == "0":
+            lport = _get_free_port()
         ssh_opts = (
             [
                 "-L",
-                "{}{}:{}{}".format(formatted_lhost, lport, formatted_dhost, dport),
+                f"{formatted_lhost}{lport}:{formatted_dhost}{dport}",
             ]
             if not reverse
             else [
                 "-R",
-                "{}{}:{}{}".format(formatted_dhost, dport, formatted_lhost, lport),
+                f"{formatted_dhost}{dport}:{formatted_lhost}{lport}",
             ]
         )
         proc = self.popen((), ssh_opts=ssh_opts, new_session=True)
         return SshTunnel(
             ShellSession(
                 proc, self.custom_encoding, connect_timeout=self.connect_timeout
-            )
+            ),
+            lport,
+            dport,
+            reverse,
         )
 
-    def _translate_drive_letter(self, path):
+    @staticmethod
+    def _translate_drive_letter(path):
         # replace c:\some\path with /c/some/path
         path = str(path)
         if ":" in path:
-            path = "/" + path.replace(":", "").replace("\\", "/")
+            return "/" + path.replace(":", "").replace("\\", "/")
         return path
 
-    @_setdoc(BaseRemoteMachine)
     def download(self, src, dst):
         if isinstance(src, LocalPath):
-            raise TypeError("src of download cannot be {!r}".format(src))
+            raise TypeError(f"src of download cannot be {src!r}")
         if isinstance(src, RemotePath) and src.remote != self:
-            raise TypeError("src {!r} points to a different remote machine".format(src))
+            raise TypeError(f"src {src!r} points to a different remote machine")
         if isinstance(dst, RemotePath):
-            raise TypeError("dst of download cannot be {!r}".format(dst))
+            raise TypeError(f"dst of download cannot be {dst!r}")
         if IS_WIN32:
             src = self._translate_drive_letter(src)
             dst = self._translate_drive_letter(dst)
-        self._scp_command("{}:{}".format(self._fqhost, shquote(src)), dst)
+        self._scp_command(f"{self._fqhost}:{shquote(src)}", dst)
 
-    @_setdoc(BaseRemoteMachine)
     def upload(self, src, dst):
         if isinstance(src, RemotePath):
-            raise TypeError("src of upload cannot be {!r}".format(src))
+            raise TypeError(f"src of upload cannot be {src!r}")
         if isinstance(dst, LocalPath):
-            raise TypeError("dst of upload cannot be {!r}".format(dst))
+            raise TypeError(f"dst of upload cannot be {dst!r}")
         if isinstance(dst, RemotePath) and dst.remote != self:
-            raise TypeError("dst {!r} points to a different remote machine".format(dst))
+            raise TypeError(f"dst {dst!r} points to a different remote machine")
         if IS_WIN32:
             src = self._translate_drive_letter(src)
             dst = self._translate_drive_letter(dst)
-        self._scp_command(src, "{}:{}".format(self._fqhost, shquote(dst)))
+        self._scp_command(src, f"{self._fqhost}:{shquote(dst)}")
 
 
 class PuttyMachine(SshMachine):
@@ -361,7 +397,7 @@ class PuttyMachine(SshMachine):
             user = local.env.user
         if port is not None:
             ssh_opts.extend(["-P", str(port)])
-            scp_opts = list(scp_opts) + ["-P", str(port)]
+            scp_opts = [*list(scp_opts), "-P", str(port)]
             port = None
         SshMachine.__init__(
             self,
@@ -379,13 +415,12 @@ class PuttyMachine(SshMachine):
         )
 
     def __str__(self):
-        return "putty-ssh://{}".format(self._fqhost)
+        return f"putty-ssh://{self._fqhost}"
 
     def _translate_drive_letter(self, path):
         # pscp takes care of windows paths automatically
         return path
 
-    @_setdoc(BaseRemoteMachine)
     def session(self, isatty=False, new_session=False):
         return ShellSession(
             self.popen((), (["-t"] if isatty else ["-T"]), new_session=new_session),
