@@ -72,8 +72,7 @@ class GeetCommit(cli.Application):
     def main(self):
         if self.parent.debug:
             return "committing in debug"
-        else:
-            return "committing"
+        return "committing"
 
     def cleanup(self, retcode):
         self.parent.cleanups.append(2)
@@ -237,7 +236,6 @@ class TestCLI:
 
     # Testing #371
     def test_extra_args(self, capsys):
-
         _, rc = PositionalApp.run(["positionalapp"], exit=False)
         assert rc != 0
         stdout, stderr = capsys.readouterr()
@@ -298,7 +296,7 @@ class TestCLI:
             assert "  DEF" in stdout
             assert "   - Item" in stdout
             # List items should not be combined into paragraphs
-            assert "  * Star 2"
+            assert "  * Star 2" in stdout
             # Lines of the same list item should be combined. (The right-hand expression of the 'or' operator
             # below is for when the terminal is too narrow, causing "GHI" to be wrapped to the next line.)
             assert "  GHI" not in stdout or "     GHI" in stdout
@@ -367,7 +365,6 @@ class TestCLI:
         assert inst.eggs == "raw"
 
     def test_mandatory_env_var(self, capsys):
-
         _, rc = SimpleApp.run(["arg"], exit=False)
         assert rc == 2
         stdout, stderr = capsys.readouterr()
