@@ -59,7 +59,7 @@ def test_connection():
     SshMachine(TEST_HOST)
 
 
-def test_incorrect_login(sshpass):
+def test_incorrect_login(sshpass):  # noqa: ARG001
     with pytest.raises(IncorrectLogin):
         SshMachine(
             TEST_HOST,
@@ -74,7 +74,7 @@ def test_incorrect_login(sshpass):
 
 
 @pytest.mark.xfail(env.LINUX, reason="TODO: no idea why this fails on linux")
-def test_hostpubkey_unknown(sshpass):
+def test_hostpubkey_unknown(sshpass):  # noqa: ARG001
     with pytest.raises(HostPublicKeyUnknown):
         SshMachine(
             TEST_HOST,
@@ -91,18 +91,18 @@ class TestRemotePath:
     def test_name(self):
         name = RemotePath(self._connect(), "/some/long/path/to/file.txt").name
         assert isinstance(name, str)
-        assert "file.txt" == str(name)
+        assert str(name) == "file.txt"
 
     def test_dirname(self):
         name = RemotePath(self._connect(), "/some/long/path/to/file.txt").dirname
         assert isinstance(name, RemotePath)
-        assert "/some/long/path/to" == str(name)
+        assert str(name) == "/some/long/path/to"
 
     def test_uri(self):
         p1 = RemotePath(self._connect(), "/some/long/path/to/file.txt")
-        assert "ftp://" == p1.as_uri("ftp")[:6]
-        assert "ssh://" == p1.as_uri("ssh")[:6]
-        assert "/some/long/path/to/file.txt" == p1.as_uri()[-27:]
+        assert p1.as_uri("ftp")[:6] == "ftp://"
+        assert p1.as_uri("ssh")[:6] == "ssh://"
+        assert p1.as_uri()[-27:] == "/some/long/path/to/file.txt"
 
     def test_stem(self):
         p = RemotePath(self._connect(), "/some/long/path/to/file.txt")
@@ -148,15 +148,14 @@ class TestRemotePath:
 
     @skip_without_chown
     def test_chown(self):
-        with self._connect() as rem:
-            with rem.tempdir() as dir:
-                p = dir / "foo.txt"
-                p.write(b"hello")
-                # because we're connected to localhost, we expect UID and GID to be the same
-                assert p.uid == os.getuid()
-                assert p.gid == os.getgid()
-                p.chown(p.uid.name)
-                assert p.uid == os.getuid()
+        with self._connect() as rem, rem.tempdir() as dir:
+            p = dir / "foo.txt"
+            p.write(b"hello")
+            # because we're connected to localhost, we expect UID and GID to be the same
+            assert p.uid == os.getuid()
+            assert p.gid == os.getgid()
+            p.chown(p.uid.name)
+            assert p.uid == os.getuid()
 
     def test_parent(self):
         p1 = RemotePath(self._connect(), "/some/long/path/to/file.txt")
@@ -182,7 +181,7 @@ class TestRemotePath:
             assert not tmp.exists()
 
     @pytest.mark.xfail(
-        reason="mkdir's mode argument is not yet implemented " "for remote paths",
+        reason="mkdir's mode argument is not yet implemented for remote paths",
         strict=True,
     )
     def test_mkdir_mode(self):
@@ -229,7 +228,6 @@ class TestRemotePath:
 
         with self._connect() as rem:
             with rem.tempdir() as tmp:
-
                 # setup a file and make sure it exists...
                 (tmp / "file_a").touch()
                 assert (tmp / "file_a").exists()
@@ -322,20 +320,22 @@ s.close()
                 rem["pwd"]()
 
     def test_glob(self):
-        with self._connect() as rem:
-            with rem.cwd(os.path.dirname(os.path.abspath(__file__))):
-                filenames = [f.name for f in rem.cwd // ("*.py", "*.bash")]
-                assert "test_remote.py" in filenames
-                assert "slow_process.bash" in filenames
+        with self._connect() as rem, rem.cwd(
+            os.path.dirname(os.path.abspath(__file__))
+        ):
+            filenames = [f.name for f in rem.cwd // ("*.py", "*.bash")]
+            assert "test_remote.py" in filenames
+            assert "slow_process.bash" in filenames
 
     def test_glob_spaces(self):
-        with self._connect() as rem:
-            with rem.cwd(os.path.dirname(os.path.abspath(__file__))):
-                filenames = [f.name for f in rem.cwd // ("*space.txt")]
-                assert "file with space.txt" in filenames
+        with self._connect() as rem, rem.cwd(
+            os.path.dirname(os.path.abspath(__file__))
+        ):
+            filenames = [f.name for f in rem.cwd // ("*space.txt")]
+            assert "file with space.txt" in filenames
 
-                filenames = [f.name for f in rem.cwd // ("*with space.txt")]
-                assert "file with space.txt" in filenames
+            filenames = [f.name for f in rem.cwd // ("*with space.txt")]
+            assert "file with space.txt" in filenames
 
     def test_cmd(self):
         with self._connect() as rem:
@@ -433,11 +433,11 @@ s.close()
 
     def test_iter_lines_error(self):
         with self._connect() as rem:
-            with pytest.raises(ProcessExecutionError) as ex:
+            with pytest.raises(ProcessExecutionError) as ex:  # noqa: PT012
                 for i, _lines in enumerate(rem["ls"]["--bla"].popen()):  # noqa: B007
                     pass
                 assert i == 1
-            assert "/bin/ls: " in ex.value.stderr
+            assert "ls: " in ex.value.stderr
 
     def test_touch(self):
         with self._connect() as rem:
@@ -466,7 +466,6 @@ class TestRemoteMachine(BaseRemoteMachineTest):
 
     @pytest.mark.parametrize("dynamic_lport", [False, True])
     def test_tunnel(self, dynamic_lport):
-
         for tunnel_prog in (self.TUNNEL_PROG_AF_INET, self.TUNNEL_PROG_AF_UNIX):
             with self._connect() as rem:
                 p = (rem.python["-u"] << tunnel_prog).popen()
@@ -477,10 +476,7 @@ class TestRemoteMachine(BaseRemoteMachineTest):
                 except ValueError:
                     dhost = None
 
-                if not dynamic_lport:
-                    lport = 12222
-                else:
-                    lport = 0
+                lport = 12222 if not dynamic_lport else 0
 
                 with rem.tunnel(lport, port_or_socket, dhost=dhost) as tun:
                     if not dynamic_lport:
@@ -501,7 +497,6 @@ class TestRemoteMachine(BaseRemoteMachineTest):
 
     @pytest.mark.parametrize("dynamic_dport", [False, True])
     def test_reverse_tunnel(self, dynamic_dport):
-
         lport = 12223 + dynamic_dport
         with self._connect() as rem:
             queue = Queue()
@@ -510,7 +505,6 @@ class TestRemoteMachine(BaseRemoteMachineTest):
             message = str(time.time())
 
             if not dynamic_dport:
-
                 get_unbound_socket_remote = """import sys, socket
 s = socket.socket()
 s.bind(("", 0))
