@@ -11,7 +11,7 @@ class TestTypedEnv:
             I = TypedEnv.Int("INT INTEGER".split())  # noqa: E741  # noqa: E741
             INTS = TypedEnv.CSV("CS_INTS", type=int)
 
-        raw_env = dict(TERM="xterm", CS_INTS="1,2,3,4")
+        raw_env = {"TERM": "xterm", "CS_INTS": "1,2,3,4"}
         e = E(raw_env)
 
         assert e.terminal == "xterm"
@@ -35,25 +35,25 @@ class TestTypedEnv:
         e.B = False
         assert raw_env["BOOL"] == "no"
 
-        assert e.INTS == [1, 2, 3, 4]
+        assert [1, 2, 3, 4] == e.INTS
         e.INTS = [1, 2]
-        assert e.INTS == [1, 2]
+        assert [1, 2] == e.INTS
         e.INTS = [1, 2, 3, 4]
 
         with pytest.raises(KeyError):
-            e.I
+            e.I  # noqa: B018
 
         raw_env["INTEGER"] = "4"
-        assert e.I == 4  # noqa: E741
+        assert e.I == 4
         assert e["I"] == 4
 
-        e.I = "5"  # noqa: E741
+        e.I = "5"
         assert raw_env["INT"] == "5"
-        assert e.I == 5  # noqa: E741
+        assert e.I == 5
         assert e["I"] == 5
 
         assert "{I} {B} {terminal}".format(**e) == "5 False foo"
-        assert dict(e) == dict(I=5, B=False, terminal="foo", INTS=[1, 2, 3, 4])
+        assert dict(e) == {"I": 5, "B": False, "terminal": "foo", "INTS": [1, 2, 3, 4]}
 
         r = TypedEnv(raw_env)
         assert "{INT} {BOOL} {TERM}".format(**r) == "5 no foo"
